import{u as A,l as r}from"./index.7377ee90.js";import{U as y}from"./constants.a8a14dc3.js";import{a as E}from"./allowed.783682a3.js";import{j as I}from"./helpers.53868b98.js";import{c as v}from"./news-sitemap.3092e2bf.js";import{C as P}from"./GettingStarted.1f73d30d.js";import{C as b}from"./Index.a76253da.js";import{G as C,a as D}from"./Row.df38a5f6.js";import{S as T}from"./Book.74a13fcd.js";import"./translations.d159963e.js";import{_ as G}from"./_plugin-vue_export-helper.eefbdd86.js";import{s as n,_ as t}from"./default-i18n.20001971.js";import{c as k,k as m,b as S,l as s,a,C as i,v as l,o as c,x as g,t as u,F as L,J as B}from"./runtime-dom.esm-bundler.5c3c7d72.js";import"./Caret.a21d4ca8.js";import"./Rocket.50a36aac.js";const e="all-in-one-seo-pack",R={setup(){return{rootStore:A()}},components:{CoreGettingStarted:P,Cta:b,GridColumn:C,GridRow:D,SvgBook:T},data(){return{UPSELL_FEATURE_LIST:y,links:r,allowed:E,ctaImg:v,strings:{cta:{title:n(t("Get %1$s %2$s and Unlock all the Powerful Features",e),"AIOSEO","Pro"),header:n(t("Get %1$s %2$s and Unlock all the Powerful Features.",e),"AIOSEO","Pro"),button:n(t("Upgrade to %1$s Today",e),"Pro")},videos:{title:t("Video Tutorials",e),linkText:t("View all video tutorials",e),linkUrl:"https://changeme"},documentation:{title:n(t("%1$s Documentation",e),"AIOSEO"),linkText:t("See our full documentation",e),linkUrl:r.getDocUrl("home")}},videos:{video1:{title:t("Basic Guide to Google Analytics",e),url:"https://changeme"},video2:{title:t("Basic Guide to Google Search Console",e),url:"https://changeme"},video3:{title:t("Best Practices for Domains and URLs",e),url:"https://changeme"},video4:{title:t("How to Control Search Results",e),url:"https://changeme"},video5:{title:n(t("Installing %1$s %2$s",e),"AIOSEO","Pro"),url:"https://changeme"},video6:{title:t("Optimizing your Content Headings",e),url:"https://changeme"}},docs:{doc1:{title:"How do I use your API code examples?",url:r.getDocUrl("apiCodeExamples")},doc2:{title:"What are media attachments and should I submit them to search engines?",url:r.getDocUrl("whatAreMediaAttachments")},doc3:{title:"When to use NOINDEX or the robots.txt?",url:r.getDocUrl("whenToUseNoindex")},doc4:{title:"How do I troubleshoot issues with AIOSEO?",url:r.getDocUrl("troubleshootIssues")},doc5:{title:"How does the import process for SEO data work?",url:r.getDocUrl("importProcessSeoData")},doc6:{title:"Installation instructions for AIOSEO Pro",url:r.getDocUrl("installAioseoPro")},doc87:{title:"What are the minimum requirements for All in One SEO?",url:r.getDocUrl("minimumRequirements")}}}},computed:{upgradeToday(){return n(t("%1$s %2$s comes with many additional features to help take your site's SEO to the next level!",e),"AIOSEO","Pro")}},methods:{getAssetUrl:I}},N={class:"aioseo-getting-started"},F=["src"],V={class:"aioseo-getting-started-documentation"},H=["href"],W={class:"d-flex"},q=["href"];function z(j,J,M,p,o,_){const U=l("core-getting-started"),O=l("cta"),d=l("grid-column"),h=l("grid-row"),w=l("svg-book");return c(),k("div",N,[o.allowed("aioseo_setup_wizard")?(c(),m(U,{key:0,"disable-close":""})):S("",!0),p.rootStore.isPro?S("",!0):(c(),m(O,{key:1,class:"aioseo-getting-started-cta",type:2,floating:!1,"button-text":o.strings.cta.button,"cta-link":o.links.utmUrl("getting-started","main-cta"),"learn-more-link":o.links.getUpsellUrl("getting-started","main-cta",p.rootStore.isPro?"pricing":"liteUpgrade"),"feature-list":o.UPSELL_FEATURE_LIST,showLink:!1},{"header-text":s(()=>[g(u(o.strings.cta.header),1)]),description:s(()=>[g(u(_.upgradeToday),1)]),"featured-image":s(()=>[a("img",{alt:"Getting Started with AIOSEO",src:_.getAssetUrl(o.ctaImg)},null,8,F)]),_:1},8,["button-text","cta-link","learn-more-link","feature-list"])),a("div",V,[i(h,{class:"header"},{default:s(()=>[i(d,{class:"header-title",sm:"6",md:"6"},{default:s(()=>[g(u(o.strings.documentation.title),1)]),_:1}),i(d,{sm:"6",md:"6",class:"header-link"},{default:s(()=>[a("a",{href:o.strings.documentation.linkUrl,target:"_blank"},u(o.strings.documentation.linkText)+" → ",9,H)]),_:1})]),_:1}),i(h,{class:"docs"},{default:s(()=>[(c(!0),k(L,null,B(o.docs,(f,x)=>(c(),m(d,{class:"doc",key:x,sm:"12",md:"6"},{default:s(()=>[a("div",W,[i(w),a("a",{href:f.url,target:"_blank"},u(f.title),9,q)])]),_:2},1024))),128))]),_:1})])])}const ct=G(R,[["render",z]]);export{ct as default};
